# Lemmy - Ansible role
This role covers deployment, configuration and software updates of Lemmy. This role is released under MIT Licence and we give no warranty for this piece of software. Currently supported OS - Debian.

You can deploy test instance using `Vagrantfile` attached to the role.

However, to have this role working with Vagrant, you have to get a self-signed certificate. If you don't want it, simply change the var `selfsigned` from `true` to `false`.

Then simply:
`vagrant up`

`ansible-playbook -b Playbooks/lemmy.yml`

Add `192.168.33.25    lemmy.example.lan` to `/etc/hosts`
Then you can access lemmy from your computer on https://lemmy.example.lan


## Playbook
The playbook includes postgresql, nginx and node roles and deploys entire stack needed to run lemmy. Additional roles are also available in the Ansible roles repos in git.


## Information
* As backend, frontend, pict-rs and imagemagick are built, the server needs some GB for disk (at least 12GB) and for memory (at least 2GB, probable better with 4GB).
* It also means that on first run, it takes some time...
* As pict-rs needs imagemagick 7.x but Debian version is 6.9, this role installs imagemagick using the IMEI (ImageMagick Easy Install) script (See https://git.asonix.dog/asonix/pict-rs/src/branch/main/docs/ubuntu-and-debian.md and https://github.com/SoftCreatR/imei)


## Tags
You can use several tags when you deploy:
- `backend`: to deploy just backend
- `ui`: to deploy just ui
- `config`: to deploy just config
- `pictrs`: to deploy pictrs and imagemagick
- `imagemagick`: to deploy just imagemagick
- `purge`: to purge the deps built files of pictrs and backend


## CHANGELOG
- **24.12.2023** - Add purge task
- **02.12.2023** - Role update
- **12.11.2022** - Role creation



## Still need to be fixed or done:

### pict-rs version
Problem building pict-rs, the only version that works is the v0.5.0-beta.2.
That means that you can now build backend with pict-rs emebeded `cargo build --release --features embed-pictrs`. This could be added once this is possible.

### In config.hjson:
`cache_external_link_previews: true` and `upload_timeout: 30` are commented out coz the server would not start with those enabled. I don't understand why.

### In lemmy.service
`Environment=LEMMY_CONFIG_LOCATION` doesn't work, so I had to set config in `config/config.hjson` as default required.
See https://join-lemmy.org/docs/administration/configuration.html

### Theming
See https://join-lemmy.org/docs/administration/theming.html
